# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ual.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tual.proto\x12\x03ual\"\x9b\x01\n\nUALMessage\x12\x1b\n\x06header\x18\x01 \x01(\x0b\x32\x0b.ual.Header\x12\x1d\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\n.ual.GraphH\x00\x12#\n\thandshake\x18\x04 \x01(\x0b\x32\x0e.ual.HandshakeH\x00\x12!\n\tsignature\x18\x03 \x01(\x0b\x32\x0e.ual.SignatureB\t\n\x07payload\"\xd9\x02\n\x06Header\x12\x11\n\tsender_id\x18\x01 \x01(\t\x12\x13\n\x0breceiver_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x12\n\nmessage_id\x18\x04 \x01(\t\x12\x18\n\x10protocol_version\x18\x05 \x01(\t\x12\x15\n\rsemantic_hash\x18\x06 \x01(\t\x12\x10\n\x08is_delta\x18\x07 \x01(\x08\x12\x13\n\x0bparent_hash\x18\x08 \x01(\t\x12\x0f\n\x07urgency\x18\t \x01(\x02\x12 \n\x05style\x18\n \x01(\x0e\x32\x11.ual.Header.Style\x12*\n\tenv_frame\x18\x0b \x01(\x0b\x32\x17.ual.EnvironmentalFrame\"I\n\x05Style\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\x0b\n\x07\x43OMMAND\x10\x02\x12\x0e\n\nSUGGESTION\x10\x03\x12\t\n\x05\x41LERT\x10\x04\"l\n\x12\x45nvironmentalFrame\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x03(\x02\x12\x13\n\x0borientation\x18\x03 \x03(\x02\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x01\"i\n\x05Graph\x12\x18\n\x05nodes\x18\x01 \x03(\x0b\x32\t.ual.Node\x12\x18\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\t.ual.Edge\x12\x12\n\ncontext_id\x18\x03 \x01(\t\x12\x18\n\x10removed_node_ids\x18\x04 \x03(\t\"\xd0\x02\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bsemantic_id\x18\x02 \x01(\r\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.ual.Node.NodeType\x12\x11\n\x07str_val\x18\x04 \x01(\tH\x00\x12\x11\n\x07num_val\x18\x05 \x01(\x01H\x00\x12\x12\n\x08\x62ool_val\x18\x06 \x01(\x08H\x00\x12\x12\n\x08\x62lob_val\x18\x07 \x01(\x0cH\x00\x12 \n\tembedding\x18\x08 \x01(\x0b\x32\x0b.ual.VectorH\x00\x12\x1e\n\ndefinition\x18\t \x01(\x0b\x32\n.ual.Graph\"l\n\x08NodeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\n\n\x06\x41\x43TION\x10\x02\x12\x0c\n\x08PROPERTY\x10\x03\x12\t\n\x05LOGIC\x10\x04\x12\t\n\x05MODAL\x10\x05\x12\t\n\x05VALUE\x10\x06\x12\x0c\n\x08\x44\x41TA_REF\x10\x07\x42\x07\n\x05value\"\xed\x01\n\x04\x45\x64ge\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x11\n\ttarget_id\x18\x02 \x01(\t\x12(\n\x08relation\x18\x03 \x01(\x0e\x32\x16.ual.Edge.RelationType\x12\x0e\n\x06weight\x18\x04 \x01(\x02\"\x84\x01\n\x0cRelationType\x12\x0e\n\nDEPENDS_ON\x10\x00\x12\x08\n\x04NEXT\x10\x01\x12\r\n\tATTRIBUTE\x10\x02\x12\x0c\n\x08\x41RGUMENT\x10\x03\x12\r\n\tCONDITION\x10\x04\x12\x0f\n\x0b\x43ONSEQUENCE\x10\x05\x12\x0f\n\x0b\x41LTERNATIVE\x10\x06\x12\x0c\n\x08TEMPORAL\x10\x07\"\x18\n\x06Vector\x12\x0e\n\x06values\x18\x01 \x03(\x02\"b\n\tHandshake\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x02 \x03(\t\x12\x12\n\npublic_key\x18\x03 \x01(\t\x12\x19\n\x11\x61\x63tive_namespaces\x18\x04 \x03(\t\"D\n\tSignature\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x11\n\tsigner_id\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UALMESSAGE']._serialized_start=19
  _globals['_UALMESSAGE']._serialized_end=174
  _globals['_HEADER']._serialized_start=177
  _globals['_HEADER']._serialized_end=522
  _globals['_HEADER_STYLE']._serialized_start=449
  _globals['_HEADER_STYLE']._serialized_end=522
  _globals['_ENVIRONMENTALFRAME']._serialized_start=524
  _globals['_ENVIRONMENTALFRAME']._serialized_end=632
  _globals['_GRAPH']._serialized_start=634
  _globals['_GRAPH']._serialized_end=739
  _globals['_NODE']._serialized_start=742
  _globals['_NODE']._serialized_end=1078
  _globals['_NODE_NODETYPE']._serialized_start=961
  _globals['_NODE_NODETYPE']._serialized_end=1069
  _globals['_EDGE']._serialized_start=1081
  _globals['_EDGE']._serialized_end=1318
  _globals['_EDGE_RELATIONTYPE']._serialized_start=1186
  _globals['_EDGE_RELATIONTYPE']._serialized_end=1318
  _globals['_VECTOR']._serialized_start=1320
  _globals['_VECTOR']._serialized_end=1344
  _globals['_HANDSHAKE']._serialized_start=1346
  _globals['_HANDSHAKE']._serialized_end=1444
  _globals['_SIGNATURE']._serialized_start=1446
  _globals['_SIGNATURE']._serialized_end=1514
# @@protoc_insertion_point(module_scope)
